From a5469ae4e0668c36e4bf36bf7395fa25073b0bc6 Mon Sep 17 00:00:00 2001
From: isanae <14251494+isanae@users.noreply.github.com>
Date: Sun, 8 Nov 2020 22:07:15 -0500
Subject: renamed SingleInstance to MOMultiProcess rewrote some comments to
avoid using "instance"
---
src/singleinstance.h | 48 ++++++++++++++----------------------------------
1 file changed, 14 insertions(+), 34 deletions(-)
(limited to 'src/singleinstance.h')
diff --git a/src/singleinstance.h b/src/singleinstance.h
index 5f6c3633..810e63d2 100644
--- a/src/singleinstance.h
+++ b/src/singleinstance.h
@@ -1,24 +1,5 @@
-/*
-Copyright (C) 2012 Sebastian Herbord. All rights reserved.
-
-This file is part of Mod Organizer.
-
-Mod Organizer is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
-
-Mod Organizer is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with Mod Organizer. If not, see .
-*/
-
-#ifndef SINGLEINSTANCE_H
-#define SINGLEINSTANCE_H
+#ifndef MODORGANIZER_MOMULTIPROCESS_INCLUDED
+#define MODORGANIZER_MOMULTIPROCESS_INCLUDED
#include
#include
@@ -26,30 +7,29 @@ along with Mod Organizer. If not, see .
/**
* used to ensure only a single instance of Mod Organizer is started and to
* allow ephemeral instances to send messages to the primary (visible) one.
* This way, other instances can start a download in the primary one
**/
-class SingleInstance : public QObject
+class MOMultiProcess : public QObject
{
-
Q_OBJECT
public:
// `allowMultiple`: if another instance is running, run this one
// disconnected from the shared memory
- explicit SingleInstance(bool allowMultiple, QObject *parent = 0);
+ explicit MOMultiProcess(bool allowMultiple, QObject *parent = 0);
/**
* @return true if this instance's job is to forward data to the primary
* instance through shared memory
**/
bool ephemeral() const
{
return m_Ephemeral;
}
// returns true if this is not the primary instance, but was allowed because
// of the AllowMultiple flag
//
bool secondary() const
@@ -58,7 +38,7 @@ public:
}
/**
* send a message to the primary instance. This can be used to transmit download urls
*
* @param message message to send
**/
@@ -67,7 +47,7 @@ public:
signals:
/**
* @brief emitted when an ephemeral instance has sent a message (to us)
*
* @param message the message we received
**/
@@ -87,4 +67,4 @@ private:
};
-#endif // SINGLEINSTANCE_H
+#endif // MODORGANIZER_MOMULTIPROCESS_INCLUDED
@@ -26,30 +7,29 @@ along with Mod Organizer. If not, see .
/**
- * used to ensure only a single instance of Mod Organizer is started and to
- * allow ephemeral instances to send messages to the primary (visible) one.
- * This way, other instances can start a download in the primary one
+ * used to ensure only a single process of Mod Organizer is started and to
+ * allow ephemeral processes to send messages to the primary (visible) one.
+ * This way, other processes can start a download in the primary one
**/
@@ -26,30 +7,29 @@ along with Mod Organizer. If not, see .
Q_OBJECT
public:
- // `allowMultiple`: if another instance is running, run this one
+ // `allowMultiple`: if another process is running, run this one
// disconnected from the shared memory
@@ -26,30 +7,29 @@ along with Mod Organizer. If not, see .
/**
- * @return true if this instance's job is to forward data to the primary
- * instance through shared memory
+ * @return true if this process's job is to forward data to the primary
+ * process through shared memory
**/
bool ephemeral() const
@@ -26,30 +7,29 @@ along with Mod Organizer. If not, see .
return m_Ephemeral;
}
- // returns true if this is not the primary instance, but was allowed because
+ // returns true if this is not the primary process, but was allowed because
// of the AllowMultiple flag
//
@@ -58,7 +38,7 @@ public:
}
/**
- * send a message to the primary instance. This can be used to transmit download urls
+ * send a message to the primary process. This can be used to transmit download urls
*
* @param message message to send
@@ -67,7 +47,7 @@ public:
signals:
/**
- * @brief emitted when an ephemeral instance has sent a message (to us)
+ * @brief emitted when an ephemeral process has sent a message (to us)
*
* @param message the message we received
--
cgit v1.3.1